package cs315.jross.hwk1;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.graphics.Paint.Style;
import android.util.AttributeSet;
import android.view.View;

/**
 * A starter class for doing simple drawing on Android.
 * This class simply overrides View, providing for simple but low-performance drawing
 * (see http://developer.android.com/guide/topics/graphics/2d-graphics.html#on-view)
 * 
 * @author Joel
 * @version Fall 2013
 */
public class DrawingView extends View
{
	private int _viewWidth;
	private int _viewHeight;
	private Paint _redPaint;
	private Bitmap _bmp;
	
	/**
	 * We need to override all the constructors, since we don't know which will be called
	 * All the constructors eventually call init()
	 */
	public DrawingView(Context context) {
		this(context, null);
	}

	public DrawingView(Context context, AttributeSet attrs) {
		this(context, attrs, 0);
	}

	public DrawingView(Context context, AttributeSet attrs, int defaultStyle) {
		super(context, attrs, defaultStyle);
		init();
	}

	/**
	 * Override method that is called when the size of the display is specified (or changes
	 * due to rotation).
	 */
	@Override
	public void onSizeChanged(int w, int h, int oldw, int oldh)
	{
		//store new size of the view
		_viewWidth = w;
		_viewHeight = h;
		
		//create a properly-sized bitmap to draw on
		_bmp = Bitmap.createBitmap(_viewWidth, _viewHeight, Bitmap.Config.ARGB_8888);
	}
	
	/**
	 * This acts as our "constructor" method, initializing variables and such
	 */
	public void init()
	{
		_redPaint = new Paint(Paint.ANTI_ALIAS_FLAG);
		_redPaint.setColor(Color.RED);
		_redPaint.setStyle(Style.FILL);
	}

	/**
	 * Override this method to specify drawing. It is like our "paintComponent()" method.
	 */
	@Override
	public void onDraw(Canvas canvas)
	{
		super.onDraw(canvas); //make sure to have the parent do any drawing it is supposed to!

		canvas.drawColor(Color.BLACK); //black out the background
		canvas.drawCircle(_viewWidth/2.0f, _viewHeight/2.0f, 100.0f, _redPaint); //we can draw directly onto the canvas
		//see http://developer.android.com/reference/android/graphics/Canvas.html for a list of options

		for(int i=20; i<_viewWidth-20; i++)
			_bmp.setPixel(i, 100, Color.BLUE); //we can also set individual pixels in a Bitmap (like a BufferedImage)
		
		canvas.drawBitmap(_bmp,0,0,null); //and then draw the BitMap onto the canvas.
		//Canvas bmc = new Canvas(_bmp); //we can also make a canvas out of a Bitmap to draw on that (like fetching g2d from a BufferedImage)
	}
}
